==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/HttpSettingsHeaderType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p400085_="https://jakarta.ee/xml/ns/jaxb" xmlns:p45416_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the HTTP headers that will be sent for all HTTP requests.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HttpSettingsHeaderType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HttpSettingsHeaderType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice maxOccurs="unbounded" minOccurs="0">
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsHeaderEntryType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HttpSettingsHeaderType", propOrder = {
    "header"
})
public class HttpSettingsHeaderType {

    protected List<HttpSettingsHeaderEntryType> header;

    /**
     * Gets the value of the header property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the header property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getHeader().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HttpSettingsHeaderEntryType }
     * </p>
     * 
     * 
     * @return
     *     The value of the header property.
     */
    public List<HttpSettingsHeaderEntryType> getHeader() {
        if (header == null) {
            header = new ArrayList<>();
        }
        return this.header;
    }

    public boolean isSetHeader() {
        return ((this.header!= null)&&(!this.header.isEmpty()));
    }

    public void unsetHeader() {
        this.header = null;
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/HttpSettingsHeaderType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p931607_="https://jakarta.ee/xml/ns/jaxb" xmlns:p994488_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the HTTP headers that will be sent for all HTTP requests.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for HttpSettingsHeaderType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="HttpSettingsHeaderType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice maxOccurs="unbounded" minOccurs="0">
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}HttpSettingsHeaderEntryType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HttpSettingsHeaderType", propOrder = {
    "header"
})
public class HttpSettingsHeaderType {

    protected List<HttpSettingsHeaderEntryType> header;

    /**
     * Gets the value of the header property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the header property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getHeader().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HttpSettingsHeaderEntryType }
     * </p>
     * 
     * 
     * @return
     *     The value of the header property.
     */
    public List<HttpSettingsHeaderEntryType> getHeader() {
        if (header == null) {
            header = new ArrayList<>();
        }
        return this.header;
    }

    public boolean isSetHeader() {
        return ((this.header!= null)&&(!this.header.isEmpty()));
    }

    public void unsetHeader() {
        this.header = null;
    }

}
